Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1154)

Unified Diff: components/arc/arc_bridge_service.h

Issue 1701063003: Refactor ArcBridgeService detection and initialization to a separate class ArcServiceLauncher. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address reviewer feedback Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | components/arc/arc_bridge_service_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/arc/arc_bridge_service.h
diff --git a/components/arc/arc_bridge_service.h b/components/arc/arc_bridge_service.h
index 13a6e66a34a4fad3f808f3e87e44fabc54de62da..2e94ee16ffaa0fd51b452c043680ae73f726fd58 100644
--- a/components/arc/arc_bridge_service.h
+++ b/components/arc/arc_bridge_service.h
@@ -131,10 +131,10 @@ class ArcBridgeService : public ArcBridgeHost {
// switch.
static bool GetEnabled(const base::CommandLine* command_line);
- // DetectAvailability() should be called once D-Bus is available. It will
- // call CheckArcAvailability() on the session_manager. This can only be
- // called on the thread that this class was created on.
- virtual void DetectAvailability() = 0;
+ // SetDetectedAvailability() should be called once CheckArcAvailability() on
+ // the session_manager is called. This can only be called on the thread that
+ // this class was created on.
+ virtual void SetDetectedAvailability(bool availability) = 0;
// HandleStartup() should be called upon profile startup. This will only
// launch an instance if the instance service is available and it is enabled.
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | components/arc/arc_bridge_service_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698